(function() {
    var $form = $('#form-medias');
    var $alerts = $('.js-alert');
    var $progress = $('.progress');
    var $fileuploadDrag = $('.js-fileupload-drag');

    // ==================================================================
    // Helper functions
    // ==================================================================
    var replaceMedia = function (media)
    {
        var template = $('#media-template').html();

        return template.replace(/{ (\w+) }/g, function (_, k) {
            return media[k] == null ? '' : media[k];
        }); 
    };

    var appendMedia = function (html)
    {
        $('.js-thumbnails').append(html);
    };

    var processResponseObject = function (response)
    {
        return appendMedia(replaceMedia(response));
    };

    var processResponseArray = function (response)
    {
        for (var i = 0; i < response.length; i++) {
            processResponseObject(response[i]);
        }
    };


    // ======================================================================
    // Retrieving all medias
    // ======================================================================
    $.ajax({
        url: window.location.href,
        method: 'get',

        complete: function (jqXHR, textStatus) {
            if (jqXHR.responseJSON.length > 0) {
                $('.js-with-medias').show();
            } else {
                $('.js-no-medias').show();
            }

            return processResponseArray(jqXHR.responseJSON);
        }
    });

    $('#files').fileupload({
        singleFileUploads: false,
        multipart: true,

        progressall: function (e, data) {
            var progress = parseInt(data.loaded / data.total * 100, 10);
            $progress.find('.progress-bar').css('width', progress + '%');
        },

        dragover: function (e) {
            $fileuploadDrag.addClass('hover');
        },

        drop: function (e) {
            $fileuploadDrag.removeClass('hover');
        },

        add: function (e, data) {
            $progress.show();
            $fileuploadDrag.hide();

            data.submit()
                .success(function (result, textStatus, jqXHR) {
                    $('.js-with-medias').show();
                    $('.js-no-medias').hide();

                    return processResponseArray(result);
                })

                .error(function (jqXHR, textStatus, errorThrown) {
                    $alerts.show().html('');

                    for (var i = 0; i < jqXHR.responseJSON.files.length; i++) {
                        $alerts.append(jqXHR.responseJSON.files[i]);
                    }
                })

                .complete(function () {
                    $progress.hide();
                    $fileuploadDrag.show();
                });
        }
    });

    $('.medias').on('dragleave', function (e) {
        e.preventDefault();

        $('.js-fileupload-drag').removeClass('hover');
    });

    // ========================================================================
    // Updating media
    // ========================================================================
    $(document).on('submit', '.js-form-media-update', function (e) {
        var $parent, $this, id;
        e.preventDefault();

        $this   = $(this);
        $btn    = $this.find('.js-btn-submit');

        $.ajax({
            type: 'POST',
            url: $this.prop('action'),
            data: $this.serialize(),

            beforeSend: function() {
                $btn.prop('disabled', true);
            }
        })
            .error(function(error) {

            })
            .always(function() {
                $btn.prop('disabled', false);
            });
    });

    // ======================================================
    // Sorting thumbnails
    // ======================================================
    $('.js-thumbnails').sortable({
        update: function(e, ui) {
            var $thumbs = $('[data-media]')
              , order   = 0;

            $thumbs.each(function(e) {
                var $this = $(this)
                  , id = $this.data('id')
                  , token = $this.find('.js-form-media-update input[name="_token"]').val();

                order++;

                $.post($form.prop('action') + '/' + id, {
                    '_method': 'put',
                    '_token': token,
                    'order': order
                });
            });
        }
    });

}).call(this);
