@extends('manager::layouts.master')

@section('content')
    <div class="medias">
        @include('manager::partials.breadcrumb', ['pages' => [
            route($model->mediaRoute()) => $model->pageTitle(),
            trans('manager-medias::index.title')
        ]])

        <div class="page-header">
            <div class="row">
                <div class="col-sm-8">
                    <h3>{{ $model->pageTitle() }} <small>{{ trans('manager-medias::index.subtitle') }}</small></h3>
                </div>

                <div class="col-sm-4 text-right">
                    <a href="{{ route($model->mediaRoute()) }}" class="btn btn-default btn-small">
                        <i class="glyphicon glyphicon-arrow-left"></i> {{ trans('manager-medias::index.back') }}
                    </a>

                    <a href="{{ route('manager.medias.destroyAll', [$config, $model->id]) }}" class="btn btn-small btn-danger" data-delete>
                        <i class="glyphicon glyphicon-trash"></i> {{ trans('manager-medias::index.delete-all') }}
                    </a>
                </div>
            </div>
        </div><!-- .page-header -->

        <div class="alert alert-danger js-alert">
        </div>

        {!! Form::open(['url' => route('manager.medias.store', [$config, $model->id]), 'files' => true, 'class' => 'form-horizontal', 'id' => 'form-medias', 'role' => 'form']) !!}
            <fieldset>
                <legend>{{ trans('manager-medias::index.form.title') }}</legend>

                <div class="form-group">
                    {!! Form::label('files', trans('manager-medias::index.form.label'), ['class' => 'col-sm-2 control-label']) !!}

                    <div class="col-sm-8">
                        <div class="input-append">
                            {!! Form::file('files[]', ['id' => 'files', 'class' => 'form-control', 'multiple' => true, 'accept' => 'image/jpg,image/jpeg,image/png', 'required' => true]) !!}

                            <div class="box-dragging-files js-fileupload-drag">
                                <h1 class="text-primary">{{ trans('manager-medias::index.form.drag-and-drop') }}</h1>
                            </div>

                            <div class="progress">
                                <div class="progress-bar progress-bar-striped active" role="progressbar" aria-valuenow="60" aria-valuemin="0" aria-valuemax="100">
                                </div>
                            </div>

                            <p class="help-block">
                                {{ trans('manager-medias::index.form.help-text') }}<br>
                                {{ trans('manager-medias::index.form.help-size') }} <strong>{{ ini_get('post_max_size') }}B</strong>.
                            </p>
                        </div>
                    </div><!-- .controls -->
                </div><!-- .control-group -->
            </fieldset>
        {!! Form::close() !!}

        <hr>

        <div class="js-with-medias">
            <p>{{ trans('manager-medias::index.change-order') }}</p>

            <div class="row js-thumbnails"></div>
        </div>

        <div class="js-no-medias">
            <p>
                {{ trans('manager-medias::index.no-medias') }}
            </p>
        </div>
    </div>
@stop

@section('styles')
    @parent

    {!! Html::style('packages/manager-medias/stylesheets/index.css') !!}
@stop

@section('scripts')
    @parent

    <script type="html/template" id="media-template">
        <div class="col-xs-6 col-md-3 medias-list-item" data-media data-id="{ id }">
            <div class="thumbnail">
                <div class="thumbnail-box">
                    <img src="{{ $url }}/{ file }?w=200&h=200" alt="{ caption }">
                </div>

                <div class="caption">
                    {!! Form::open(['url' => Request::url() . '/{ id }', 'class' => 'js-form-media-update', 'method' => 'put']) !!}
                        <div class="form-group">
                            {!! Form::text('caption', '{ caption }', ['placeholder' => trans('manager-medias::index.form.caption'), 'class' => 'form-control input-sm']) !!}
                        </div>
                        @if (! in_array('credits', config('manager-medias.hidden')))
                            <div class="form-group">
                                {!! Form::text('credits', '{ credits }', ['placeholder' => trans('manager-medias::index.form.credits'), 'class' => 'form-control input-sm']) !!}
                            </div>
                        @endif
                        <div class="pull-right btn-group btn-group-sm">
                            <button type="submit" class="btn btn-primary btn-small js-btn-submit" title="{{ trans('manager-medias::index.form.update') }}" data-id="{ id }">
                                <span class="glyphicon glyphicon-refresh"></span>
                                {{ trans('manager-medias::index.form.update') }}
                            </button>
                            <a href="{{ Request::url() }}/{ id }" class="btn btn-danger btn-small" title="{{ trans('manager-medias::index.form.delete') }}" data-delete="true">
                                <span class="glyphicon glyphicon-trash"></span>
                                {{ trans('manager-medias::index.form.delete') }}
                            </a>
                        </div>
                    {!! Form::close() !!}
                    <div class="clearfix"></div>
                </div><!-- .caption -->
            </div>
        </div>

    </script>

    {!! Html::script('packages/manager-medias/javascript/vendor.js') !!}
    {!! Html::script('packages/manager-medias/javascript/index.js') !!}
@stop
