<?php namespace EscapeWork\Manager\Medias\Commands;

use EscapeWork\LaravelUploader\Upload;
use EscapeWork\Manager\Medias\Collections\MediaCollection;
use EscapeWork\Manager\Medias\Contracts\Mediable;
use EscapeWork\Manager\Medias\Services\MediaService;
use EscapeWork\Manager\Medias\Services\MediasResizeService;
use Illuminate\Contracts\Bus\SelfHandling;

class StoreMediasCommand extends Command implements SelfHandling
{

    /**
     * @var array|object
     */
    protected $files;

    /**
     * @var EscapeWork\Manager\Medias\Contracts\Mediable
     */
    protected $model;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct($files, Mediable $model)
    {
        $this->files = $files;
        $this->model = $model;
    }

    /**
     * Handle the command.
     *
     * @return void
     */
    public function handle(Upload $upload, MediaService $medias)
    {
        $dir   = config('manager-medias.medias.dir');
        $files = new MediaCollection($upload->to($dir)->execute($this->files));

        $files->resize($dir);

        return $medias->to($this->model)
                      ->save($files);
    }
}


