<?php namespace EscapeWork\Manager\Medias\Controllers;

use Illuminate\Http\Request;
use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Medias\Repositories\MediaRepository;
use EscapeWork\Manager\Medias\Contracts\Mediable;
use EscapeWork\Manager\Medias\Http\Requests\StoreRequest;
use EscapeWork\Manager\Medias\Commands\StoreMediasCommand;
use EscapeWork\Manager\Medias\Commands\UpdateMediasCommand;
use EscapeWork\Manager\Medias\Repositories\ConfigRepository;

class MediasController extends Controller
{

    public function __construct(Mediable $model, MediaRepository $medias)
    {
        parent::__construct();

        $this->model  = $model;
        $this->medias = $medias;
    }

    public function index(Request $request)
    {
        if ($request->ajax()) return $this->medias->getMedias();

        return view(config('manager-medias.views.medias.index'), [
            'config' => $request->model,
            'medias' => $this->medias->getMedias(),
            'model'  => $this->model,
            'url'    => config('manager-medias.medias.url'),
        ]);
    }

    public function store(StoreRequest $request)
    {
        return $this->dispatch(
            new StoreMediasCommand($request->file('files'), $this->model)
        );
    }

    public function update(Request $request)
    {
        $id = $request->id;
        if (! $media = $this->medias->findOrFail($id)) {
            return response([
                'error' => trans('manager-medias::controller.update.error'),
            ]);
        }

        $this->dispatch(new UpdateMediasCommand($media));

        return response([
            'message' => trans('manager-medias::controller.update.message'),
            'id'      => $media->id
        ]);
    }

    public function destroy(Request $request)
    {
        $media = $this->medias->findOrFail($request->id);

        if (! $media->delete()) {
            return redirect(route('manager.medias.index', [$request->model, $this->model->id]))
                        ->with('error', trans('manager-medias::controller.destroy.error'));
        }

        return redirect(route('manager.medias.index', [$request->model, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy.message'));

    }

    public function destroyAll(Request $request)
    {
        $this->medias->deleteAll();

        return redirect(route('manager.medias.index', [$request->model, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy-all.message'));
    }
}
