<?php namespace EscapeWork\Manager\Medias\Http\Middleware;

use EscapeWork\Manager\Medias\Exceptions\MediableException;
use EscapeWork\Manager\Medias\Contracts\Mediable;
use EscapeWork\Manager\Medias\Repositories\MediaRepository;
use EscapeWork\Manager\Medias\Exceptions\MediaSettingsException;
use Closure;

class MediableMiddleware {

    /**
     * Run the request filter.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @return mixed
     */
    public function handle($request, Closure $next)
    {
        $this->registerMediable($request->model, $request->model_id);
        $this->registerMedia();

        return $next($request);
    }

    protected function registerMediable($model, $id)
    {
        app()->bind('EscapeWork\Manager\Medias\Contracts\Mediable', function ($app) use ($model, $id) {
            $configModel = config("manager-medias.medias.models.$model");

            if (is_null($configModel)) throw new MediaSettingsException;

            $instance = $app->make($configModel);

            if (! ($instance instanceof Mediable)) throw new MediableException;

            return $instance->findOrFail($id);
        });
    }

    protected function registerMedia()
    {
        app()->bind('EscapeWork\Manager\Medias\Repositories\MediaRepository', function ($app) {
            $mediaRepository = new MediaRepository(
                $app->make('EscapeWork\Manager\Medias\Models\Media')
            );

            $mediable = $app->make('EscapeWork\Manager\Medias\Contracts\Mediable');

            $mediaRepository->media_model = get_class($mediable);
            $mediaRepository->model_id    = $mediable->id;

            return $mediaRepository;
        });
    }
}
