<?php namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\PresentableTrait;
use EscapeWork\Manager\Medias\Repositories\ConfigRepository;

class Media extends Model
{

    /**
     * Presentable
     */
    use PresentableTrait;

    /**
     * Presenter attribute
     */
    protected $presenter = 'EscapeWork\Manager\Medias\Presenters\MediaPresenter';

    /**
     * Table
     */
    protected $table = 'manager_medias';

    /**
     * Fields
     */
    public $fillable = [
        'id',
        'media_model',
        'model_id',
        'file',
        'mime',
        'size',
        'caption',
        'credits',
        'order',
        'active'
    ];

    /**
     * Scope for active medias only
     */
    public function scopeActive($query)
    {
        return $query->where('active', '=', true);
    }

    /**
     * Scope for default get Medias from
     */
    public function scopeGetCurrentModel($query)
    {
        return $query->where('media_model', '=', $this->media_model)
                     ->where('model_id', '=', $this->model_id);
    }

    public function scopeMediaModelFilter($query)
    {
        return $query->where('media_model', '=', $this->media_model);
    }

    public function delete()
    {
        $file = config('manager-medias.medias.dir') . '/' . $this->file;

        if (is_file($file)) {
            unlink($file);
        }

        return parent::delete();
    }

    /**
     * Polymorphical relation
     */
    public function medias()
    {
        return $this->morphTo();
    }
}
